@@ -133,7 +133,7 @@ def _reset_hal_data(hooks):
         # povs are stored as integer values
         'joysticks': [{
             'has_source': False,
-            'buttons': [False]*12, # numbered 0-11
+            'buttons': [None] + [False]*12, # numbered 1-12 -- 0 is ignored
             'axes':    [0]*constants.kMaxJoystickAxes,  # x is 0, y is 1, .. 
             'povs':    [-1]*constants.kMaxJoystickPOVs  # integers
         
@@ -163,7 +163,7 @@ def _reset_hal_data(hooks):
             'initialized': False,
             'voltage': 0.0
 
-        }) for _ in range(2)],
+        }) for _ in range(8)],
 
         # TODO: make this easier to use
         'analog_in': [NotifyDict({
@@ -253,7 +253,7 @@ def _reset_hal_data(hooks):
         'encoder': [{
             'has_source': False,
             'initialized': False,
-            'config': [None]*6, # list of pins/modules
+            'config': {}, # dictionary of pins/modules
             'count': 0,
             'period': sys.float_info.max,
             'max_period': 0,
