@@ -9,6 +9,9 @@ from .data import hal_data
 from hal_impl.sim_hooks import SimHooks
 from hal_impl.pwm_helpers import reverseByType
 
+import logging
+logger = logging.getLogger('hal')
+
 hooks = SimHooks()
 
 def reset_hal():
@@ -228,6 +231,7 @@ def getFPGAButton(status):
     return hal_data['fpga_button']
 
 def HALSetErrorData(errors, errorsLength, wait_ms):
+    logger.warn(errors.decode('utf-8').strip())
     hal_data['error_data'] = errors
 
 def HALGetControlWord():
@@ -970,7 +974,9 @@ def initializeEncoder(port_a_module, port_a_pin, port_a_analog_trigger, port_b_m
         enc = hal_data['encoder'][idx]
         if enc['initialized'] == False:
             enc['initialized'] = True
-            enc['config'] = [port_a_module, port_a_pin, port_a_analog_trigger, port_b_module, port_b_pin, port_b_analog_trigger]
+
+            enc['config'] = {"ASource_Module": port_a_module, "ASource_Channel": port_a_pin, "ASource_AnalogTrigger": port_a_analog_trigger,
+                             "BSource_Module": port_b_module, "BSource_Channel": port_b_pin, "BSource_AnalogTrigger": port_b_analog_trigger}
             enc['reverse_direction'] = reverse_direction
             return types.Encoder(idx), idx 
         
@@ -1019,6 +1025,12 @@ def getEncoderSamplesToAverage(encoder, status):
     status.value = 0
     return hal_data['encoder'][encoder.idx]['samples_to_average']
 
+def setEncoderIndexSource(encoder, pin, analogTrigger, activeHigh, edgeSensitive, status):
+    status.value = 0
+    index_conf = {"IndexSource_Channel": pin, "IndexSource_Module": 0, "IndexSource_AnalogTrigger": analogTrigger,
+                  "IndexActiveHigh": activeHigh, "IndexEdgeSensitive": edgeSensitive}
+    hal_data['encoder'][encoder.idx]['config'].update(index_conf)
+
 def getLoopTiming(status):
     status.value = 0
     return hal_data['pwm_loop_timing']
@@ -1340,17 +1352,17 @@ def c_TalonSRX_SetParam(handle, paramEnum, value):
 
 def c_TalonSRX_RequestParam(handle, paramEnum):
     params = hal_data['CAN'][handle.id]['params']
-    assert paramEnum in params, "Parameter %s not set!" # TODO: is this correct?
+    assert paramEnum in params, "Parameter %s not set!" % constants.TalonSRXParam_tostr[paramEnum] # TODO: is this correct?
     return params[paramEnum]
 
 def c_TalonSRX_GetParamResponse(handle, paramEnum):
     params = hal_data['CAN'][handle.id]['params']
-    assert paramEnum in params, "Parameter %s not set!" # TODO: is this correct?
+    assert paramEnum in params, "Parameter %s not set!" % constants.TalonSRXParam_tostr[paramEnum] # TODO: is this correct?
     return params[paramEnum]
 
 def c_TalonSRX_GetParamResponseInt32(handle, paramEnum):
     params = hal_data['CAN'][handle.id]['params']
-    assert paramEnum in params, "Parameter %s not set!" # TODO: is this correct?
+    assert paramEnum in params, "Parameter %s not set!" % constants.TalonSRXParam_tostr[paramEnum] # TODO: is this correct?
     return params[paramEnum]
 
 def c_TalonSRX_SetStatusFrameRate(handle, frameEnum, periodMs):
